import javax.swing.*;
import java.awt.*;
import java.awt.geom.Rectangle2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.image.BufferedImage;
import java.awt.image.ConvolveOp;
import java.awt.image.Kernel;

public class AquaButtonPanel extends JButton
{
	
	public static float[] BLUR = {0.10f, 0.10f, 0.10f, 0.10f, 0.30f, 0.10f, 0.10f, 0.10f, 0.10f};

	private int inset = 8;
	public Color buttonColor; 
	private Color foregroundColor = new Color(0f,0f,0f,.6f);
	Color u_farbe;
	String u_label;
	Color backfarbe = new Color(207,207,207);
	
	public AquaButtonPanel(Color col,String blabel)
	{
		u_farbe = col;
		u_label = blabel;
	}

	public void paintComponent(Graphics g)
	{
		super.paintComponent(g);
		
		buttonColor = u_farbe;
		Graphics2D g2 = (Graphics2D) g;
		g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);

		int vWidth = getWidth();
		int vHeight = getHeight();

		// Calculate the size of the button
		int vButtonHeight = vHeight - (inset * 2);
		int vButtonWidth = vWidth - (inset * 2);
		int vArcSize = vButtonHeight;

		BufferedImage vBuffer = new BufferedImage(vWidth, vHeight, BufferedImage.TYPE_INT_RGB);
		Graphics2D bg = vBuffer.createGraphics();
		bg.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);

		// Paint the background of the button
		bg.setColor(backfarbe);
		bg.fillRect(0, 0, vWidth, vHeight);

		// Create the gradient paint for the first layer of the button
		Color vGradientStartColor =  buttonColor.darker().darker().darker();
		Color vGradientEndColor = buttonColor;
		Paint vPaint = new GradientPaint(0, inset, vGradientStartColor, 0, vButtonHeight, vGradientEndColor, false);
		bg.setPaint(vPaint);

		// Paint the first layer of the button
		bg.fillRoundRect(inset, inset, vButtonWidth, vButtonHeight, vArcSize, vArcSize);

		// Calulate the size of the second layer of the button
		int vHighlightInset = 2;
		int vButtonHighlightHeight = vButtonHeight - (vHighlightInset * 2);
		int vButtonHighlightWidth = vButtonWidth - (vHighlightInset * 2);
		int vHighlightArcSize = vButtonHighlightHeight;

		// Create the paint for the second layer of the button
		vGradientStartColor = Color.WHITE;
		vGradientEndColor = buttonColor;
		vPaint = new GradientPaint(0,inset+vHighlightInset,vGradientStartColor,0,inset+vHighlightInset+(vButtonHighlightHeight/1),buttonColor, false); //changed /2 => /1

		// Paint the second layer of the button
		bg.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER,.8f));
		bg.setPaint(vPaint);
		bg.setClip(new RoundRectangle2D.Float(inset+vHighlightInset,inset+vHighlightInset,vButtonHighlightWidth,vButtonHighlightHeight/2,vButtonHighlightHeight/3,vButtonHighlightHeight/3));
		bg.fillRoundRect(inset+vHighlightInset,inset+vHighlightInset,vButtonHighlightWidth,vButtonHighlightHeight,vHighlightArcSize,vHighlightArcSize);

		// Blur the button
		ConvolveOp vBlurOp = new ConvolveOp(new Kernel(3, 3, BLUR));
		BufferedImage vBlurredBase = vBlurOp.filter(vBuffer, null);

		// Draw our aqua button
		g2.drawImage(vBlurredBase, 0, 0, null);

		// Draw the text (if any)
		if (u_label != null)
		{
			g2.setColor(foregroundColor);

			Font vFont = g2.getFont().deriveFont((float)(((float)vButtonHeight) * .3));
			g2.setFont(vFont);

			FontMetrics vMetrics = g2.getFontMetrics();
			Rectangle2D vStringBounds = vMetrics.getStringBounds(u_label,g2);

			float x = (float)((vWidth / 2) - (vStringBounds.getWidth() / 2));
			float y = (float)((vHeight / 2) + (vStringBounds.getHeight() / 2)) - vMetrics.getDescent();

			g2.drawString(u_label,x,y);
		}
	}
}